@@ -5,9 +5,9 @@
 #include <gmp.h>
 
 #include <flint/fmpz.h>
+#include <flint/fmpq.h>
 #include <flint/fmpz_poly.h>
 #include <flint/fmpz_poly_factor.h>
-#include <flint/fmpq.h>
 #include <flint/fmpq_poly.h>
 
 namespace SymEngine
@@ -710,15 +710,17 @@ public:
         fmpq_poly_init(poly);
         fmpq_poly_set_str(poly, cp);
     }
-    fmpq_poly_wrapper(const fmpz_t z)
+    fmpq_poly_wrapper(const mpz_t z)
     {
+        fmpz_wrapper fz(z);
         fmpq_poly_init(poly);
-        fmpq_poly_set_fmpz(poly, z);
+        fmpq_poly_set_fmpz(poly, fz.get_fmpz_t());
     }
-    fmpq_poly_wrapper(const fmpq_t q)
+    fmpq_poly_wrapper(const mpq_t q)
     {
+        fmpq_wrapper fq(q);
         fmpq_poly_init(poly);
-        fmpq_poly_set_fmpq(poly, q);
+        fmpq_poly_set_fmpq(poly, fq.get_fmpq_t());
     }
     fmpq_poly_wrapper(const fmpq_wrapper &q)
     {
